<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=bs
// ** ne pas modifier le fichier **

return [

	// A
	'aide_non_disponible' => 'Pomoc nije dostupna',
	'avis_acces_interdit' => 'Pristup zabranjen.',
	'avis_article_modifie' => 'Paznja, @nom_auteur_modif@ je radio na ovom artiklu prije @date_diff@ minuta',
	'avis_aucun_resultat' => 'Nije pronadjen nijedan rezultat.',
	'avis_chemin_invalide_1' => 'Opcija koju ste izabrali',
	'avis_chemin_invalide_2' => 'nije vazeca. Vratite se na  prethodnu stranicu i provjerite unesene podatke.',
	'avis_connexion_echec_1' => 'Konekcija na SQL server nije uspijela.', # MODIF
	'avis_connexion_echec_2' => 'Vratite se na prethodnu stranicu i provjerite unesene podatke.',
	'avis_connexion_echec_3' => '<b>N.B.</b> Na nekim serverima, trebate <b>traziti</b> aktiviranje pristupa SQL bazi prije nego je mozete koristiti. Ako se ne mozete konektovati provjerite da li ste trazili pomenutu aktivaciju.', # MODIF
	'avis_connexion_ldap_echec_1' => 'Konekcija na LDAP server nije uspjela.',
	'avis_connexion_ldap_echec_2' => 'Vratite se na prethodnu stranicu i provjerite unesene podatke.',
	'avis_connexion_ldap_echec_3' => 'Ne koristite podrsku LDAP kao alternativu za importovanje korisnika.', # MODIF
	'avis_deplacement_rubrique' => 'Paznja! Ova rubrika sadrzi @contient_breves@ kratke poruke: Ako je zelite premjestiti, oznacite  ovo polje kao potvrdu.',
	'avis_erreur_connexion_mysql' => 'Greska u SQL konekciji', # MODIF
	'avis_espace_interdit' => '<b>Zabranjen prostor</b><p>SPIP je  vec instaliran.</p>', # MODIF
	'avis_lecture_noms_bases_1' => 'Instalacijski program nije uspio ucitati imena instaliranih baza podataka.',
	'avis_lecture_noms_bases_2' => 'Ili nijedna baza nije na  raspolaganju, ili je funkcija, koja dozvoljava izlistavanje  baza, dezaktivirana iz sigurnosnih razloga (sto je slucaj kod  mnogih racunara).',
	'avis_lecture_noms_bases_3' => 'Ako je u pitanju druga alternativa, moguce je da se koristi baza koja nosi isto ime kao vas login:',
	'avis_non_acces_page' => 'Nemate pristup ovoj strani.',
	'avis_operation_echec' => 'Operacija nije uspijela.',
	'avis_suppression_base' => 'PAZNJA, brisanje podataka je  nepovratno',

	// B
	'bouton_acces_ldap' => 'Dodaj pristup za LDAP >>', # MODIF
	'bouton_ajouter' => 'Dodaj',
	'bouton_demande_publication' => 'Trazi publikaciju ovog clanka',
	'bouton_effacer_tout' => 'Izbrisi SVE',
	'bouton_envoyer_message' => 'Definitivna poruka: posalji',
	'bouton_modifier' => 'Izmijeni',
	'bouton_radio_afficher' => 'Prikazi',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Prikazi u listi prisutnih urednika', # MODIF
	'bouton_radio_envoi_annonces_adresse' => 'Posalji najave na adresu:',
	'bouton_radio_envoi_liste_nouveautes' => 'Posalji listu novosti',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Ne prikazuj u listi urednika', # MODIF
	'bouton_radio_non_envoi_annonces_editoriales' => 'Ne salji editorijalne najave',
	'bouton_redirection' => 'PREUSMJERI',
	'bouton_relancer_installation' => 'Ponovo pokreni instalaciju',
	'bouton_suivant' => 'Sljedece',
	'bouton_tenter_recuperation' => 'Pokusaj popraviti',
	'bouton_test_proxy' => 'Provjeri proxy',
	'bouton_vider_cache' => 'Isprazni kes',

	// C
	'cache_modifiable_webmestre' => 'Webmaster stranice moze promijeniti ovaj parametar.', # MODIF
	'calendrier_synchro' => 'Ako koristite neki kompaktibilni kalendarski software <b>iCal</b>, mozete ga uskladiti sa informacijama ove stranice.',

	// D
	'date_mot_heures' => 'sati',

	// E
	'email' => 'e-mail',
	'email_2' => 'e-mail:',
	'entree_adresse_annuaire' => 'Adresa direktorija',
	'entree_adresse_email' => 'Vasa e-mail adresa',
	'entree_base_donnee_1' => 'Adresa baze podataka',
	'entree_base_donnee_2' => '(Ova adresa cesto odgovara adresi vase stranice, nekada ona odgovara nazivu  «localhost», a nekada je ostavljena prazna.)',
	'entree_biographie' => 'Kratka biografija u nekoliko rijeci.',
	'entree_chemin_acces' => '<b>Unijeti</b> putanju pristupa:', # MODIF
	'entree_cle_pgp' => 'Vas PGP kljuc',
	'entree_contenu_rubrique' => '(Sadrzaj ove rubrike, u nekoliko  rijeci.)',
	'entree_identifiants_connexion' => 'Identifikatori vase konekcije...',
	'entree_informations_connexion_ldap' => 'U ovaj formular unesite informacije o konekciji sa LDAP direktorijem. Administrator mreze ili mreza ce vam pruziti te informacije.', # MODIF
	'entree_infos_perso' => 'Ko ste?',
	'entree_interieur_rubrique' => 'U rubrici:',
	'entree_liens_sites' => '<b>Hiperlink</b> (Reference, web stranice za posjetiti...)', # MODIF
	'entree_login' => 'Vas login',
	'entree_login_connexion_1' => 'Login konekcije',
	'entree_login_connexion_2' => '(Nekada odgovara vasem loginu za pristup na FTP; nekada je ostavljen prazan)',
	'entree_mot_passe' => 'Vasa lozinka',
	'entree_mot_passe_1' => 'Lozinka konekcije',
	'entree_mot_passe_2' => '(Nekada odgovara vasoj lozinki za pristup na FTP, a nekada je ostavljeno prazno)',
	'entree_nom_fichier' => 'Unesite ime dokumenta @texte_compresse@:',
	'entree_nom_pseudo' => 'Vase ime ili pseudo',
	'entree_nom_pseudo_1' => '(Vase ime ili pseudo)',
	'entree_nom_site' => 'Ime vase stranice',
	'entree_nouveau_passe' => 'Nova lozinka',
	'entree_passe_ldap' => 'Lozinka',
	'entree_port_annuaire' => 'Broj porta direktorija',
	'entree_signature' => 'Potpis',
	'entree_titre_obligatoire' => '<b>Naslov</b> [Obavezno]<br />', # MODIF
	'entree_url' => 'URL adresa vase stranice',

	// I
	'ical_info1' => 'Na ovoj strani je predstavljeno nekoliko metoda kako da ostanete u toku sa aktuelnostima ove web stranice.',
	'ical_info2' => 'Za sve informacije o ovim metodama, mozete konsultovati <a href="@spipnet@"> SPIP  dokumentaciju </a>.', # MODIF
	'ical_info_calendrier' => 'Na raspolaganju vam stoje dva kalendara. Jedan je plan stranice koji najavljuje sve publicirane artikle. Drugi sadrzi editorijalne najave, kao sto su vase posljednje privatne poruke: On je rezervisan za vas zahvaljujuci licnom kljucu, koji mozete izmijeniti u svakom  momentu, dok mijenjate svoju lozinku.',
	'ical_methode_http' => 'Download',
	'ical_methode_webcal' => 'Sinhronizacija (webcal://)', # MODIF
	'ical_texte_prive' => 'Ovaj kalendar, koji je iskljucivo za licnu upotrebu, obavjestava vas o privatnim editorijalnim  aktivnostima na ovoj stranici (zadaci i licni sastanci, clanci i objavljene kratke poruke).',
	'ical_texte_rss' => 'Novosti sa ove stranice mozete sindikovati u bilo kojem citacu dokumenata XML/RSS (Rich Site Summary). Takodze, to je format koji dozvoljava SPIP-u da cita novosti objavljene na drugim stranicama, koristeci kompatibilan format  za razmjenu (sindikovane stranice).',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'Mailing-lista',
	'ical_titre_rss' => 'Dokumenti « backend »',
	'icone_activer_cookie' => 'Postavi cookie',
	'icone_afficher_auteurs' => 'Prikazi autore',
	'icone_afficher_visiteurs' => 'Prikazi posjetioce',
	'icone_arret_discussion' => 'Zavrsi ucesce u ovoj diskusiji',
	'icone_calendrier' => 'Kalendar',
	'icone_creer_auteur' => 'Kreiraj novog autora i asociraj ga s ovim clankom',
	'icone_creer_mot_cle' => 'Kreiraj novu kljucnu rijec i povezi je sa ovim clankom',
	'icone_creer_rubrique_2' => 'Kreiraj novu rubriku',
	'icone_modifier_article' => 'Izmijeni ovaj clanak',
	'icone_modifier_rubrique' => 'Izmijeni ovu rubriku',
	'icone_retour' => 'Nazad',
	'icone_retour_article' => 'Nazad na clanak',
	'icone_supprimer_cookie' => 'Izbrisi cookie',
	'icone_supprimer_rubrique' => 'Izbrisi ovu rubriku',
	'icone_supprimer_signature' => 'Izbrisi ovaj potpis',
	'icone_valider_signature' => 'Ovjeri ovaj potpis',
	'image_administrer_rubrique' => 'Mozete biti administrator ove rubrike',
	'impossible_modifier_login_auteur' => 'Impossible de modifier le login.', # MODIF
	'impossible_modifier_pass_auteur' => 'Impossible de modifier le mot de passe.', # MODIF
	'info_1_article' => '1. clanak',
	'info_activer_cookie' => 'Mozete aktivirati jedan <b> cookie za administraciu </b>, koji ce vam dozvoliti lak prelaz iz javnog u privati prostor.',
	'info_administrateur' => 'Administrator', # MODIF
	'info_administrateur_1' => 'Administrator', # MODIF
	'info_administrateur_2' => 'stranice (<i>pazljiva  upotreba</i>)',
	'info_administrateur_site_01' => 'Ako ste administrator stranice', # MODIF
	'info_administrateur_site_02' => 'kliknite ovaj link',
	'info_administrateurs' => 'Administratori', # MODIF
	'info_administrer_rubrique' => 'Mozete biti administrator ove rubrike',
	'info_adresse' => 'na adresu:',
	'info_adresse_url' => 'URL adresa stranice za javnost',
	'info_aide_en_ligne' => 'Online pomoc za SPIP',
	'info_ajout_image' => 'Ako clanku dodajete fotografije u formi dokumenta, SPIP moze kreirati vinjete (minijature) dodanih  fotografija. To naprimjer dozvoljava automatsko kreiranje  galerije ili portfolija.',
	'info_ajouter_rubrique' => 'Dodaj drugu rubriku za administraciju:',
	'info_annonce_nouveautes' => 'Najava novosti',
	'info_article' => 'clanak',
	'info_article_2' => 'clanci',
	'info_article_a_paraitre' => 'Prikazi clanke sa kasnijim  datumom',
	'info_articles_02' => 'clanci',
	'info_articles_2' => 'Clanci',
	'info_articles_auteur' => 'Clanci ovog autora',
	'info_articles_trouves' => 'Pronadjeni clanci',
	'info_attente_validation' => 'Vasi clanci koji cekaju ovjeru',
	'info_aujourdhui' => 'danas:',
	'info_auteur_gere_toutes_rubriques_2' => 'Je gère <b>toutes les rubriques</b>', # MODIF
	'info_auteurs' => 'Autori',
	'info_auteurs_par_tri' => 'Autori@partri@',
	'info_auteurs_trouves' => 'Pronadjeni autori',
	'info_authentification_externe' => 'Eksterna autentifikacija',
	'info_avertissement' => 'Upozorenje',
	'info_base_installee' => 'Struktura vase baze podatake je instalirana.',
	'info_chapeau' => 'Uvod',
	'info_chapeau_2' => 'Uvod:',
	'info_chemin_acces_1' => 'Opcije: <b>Putanja pristupa u direktorij</b>', # MODIF
	'info_chemin_acces_2' => 'Od sada cete morati konfigurisati putanju pristupa informacijama iz direktorija. Ova informacija je neophodna za citanje profila korisnika koji su pohranjeni u direktoriju.', # MODIF
	'info_chemin_acces_annuaire' => 'Opcije : <b>Putanja pristupa u direktorij', # MODIF
	'info_choix_base' => 'Treca etapa :',
	'info_classement_1' => '<sup>er</sup> iz @liste@',
	'info_classement_2' => '<sup>e</sup> iz @liste@',
	'info_code_acces' => 'Ne zaboravite vas kod za pristup!',
	'info_config_suivi' => 'Ako ova adresa odgovara mailing listi, ispod mozete naznaciti adresu na koju se ucesnici mogu registrovati. Ta adresa moze biti URL (npr. strana za  upisivanje na listu putem web-a), ili e-mail adresa opremljena  specificnim subjektom(npr.:  <tt>@adresse_suivi@?subject=prijava</tt>):',
	'info_config_suivi_explication' => 'Mozete se prikljuciti mailing-listi ove stranice. Poslije cete u elektronskim putem primiti najave clanaka i kratkih poruka, koje su predlozene za publikaciju',
	'info_confirmer_passe' => 'Potvrdi novu lozinku:',
	'info_connexion_base' => 'Druga etapa: <b>Pokusaj konekcije sa bazom</b>', # MODIF
	'info_connexion_ldap_ok' => 'Uspjesna LDAP konekcija.</b><p>  Mozete pristupiti sljedecoj etapi</p>', # MODIF
	'info_connexion_mysql' => 'Prva etapa: <b>Vasa SQL konekcija</b>', # MODIF
	'info_connexion_ok' => 'Uspjesna konekcija.',
	'info_contact' => 'Kontakt',
	'info_contenu_articles' => 'Sadrzaj clanaka',
	'info_creation_paragraphe' => '(Da biste kreirali odlomke, linije ostavite prazne.)', # MODIF
	'info_creation_rubrique' => 'Prije nego mozete pisati clanke,<br /> morate kreirati najmanje jednu rubriku.<br />', # MODIF
	'info_creation_tables' => 'Cetvrta etapa: <b>Kreiranje tabela baze</b>', # MODIF
	'info_creer_base' => '<b>Kreirati</b> novu bazu podataka:', # MODIF
	'info_dans_rubrique' => 'U rubrici:',
	'info_date_publication_anterieure' => 'Datum proslog objavljivanja:',
	'info_date_referencement' => 'DATUM PREPORUKE OVE STRANICE:',
	'info_derniere_etape' => 'Posljednja etapa: <b>Zavrseno je!', # MODIF
	'info_descriptif' => 'Opis:',
	'info_discussion_cours' => 'Aktivne diskusije',
	'info_ecrire_article' => 'Prije nego mozete pisati clanke, morate kreirati najmanje jednu rubriku.',
	'info_email_envoi' => 'E-mail adresa za slanje (fakultativno)',
	'info_email_envoi_txt' => 'Ovdje oznacite adresu za slanje e-mailova (po standardu ce adresa primaoca biti koristena kao adresa za slanje):',
	'info_email_webmestre' => 'E-mail adresa webmastera (fakultativno)', # MODIF
	'info_envoi_email_automatique' => 'Automatsko slanje e-mailova',
	'info_envoyer_maintenant' => 'Posalji sada',
	'info_etape_suivante' => 'Pristupi sljedecoj etapi',
	'info_etape_suivante_1' => 'Mozete pristupiti sljedecoj etapi.',
	'info_etape_suivante_2' => 'Mozete pristupiti sljedecoj etapi.',
	'info_exportation_base' => 'eksportuj baze u @archive@',
	'info_facilite_suivi_activite' => 'U svrhu posmatranja  editorijalne aktivnosti stranice, SPIP moze elektronskom postom  (npr. mailing listom urednika) proslijedjivati najave zahtijeva za publikaciju i ovjeru clanaka.', # MODIF
	'info_fichiers_authent' => 'Dokument autentifikacije « .htpasswd »',
	'info_forums_abo_invites' => 'Vasa stranica obudhvata i forume za clanove; posjetioci se pozivaju na registraciju u javnom  prostoru stanice.', # MODIF
	'info_gauche_admin_tech' => '<b>Ova strana je dostupna samo osobama odgovornim za web stranicu.</b><p> Ona daje pristup raznim funkcijama tehnickog odrzavanja. Neke od njih pruzaju  mogucnost specificne autentifikacije, koja zahtijeva pristup FTP-u web stranice.</p>', # MODIF
	'info_gauche_auteurs' => 'Ovdje cete pronaci sve autore ove web stranice. Njihov status je naznacen bojom njihove ikone (administrator = zelena; urednik = zuta).', # MODIF
	'info_gauche_auteurs_exterieurs' => 'Vanjski autori bez pristupa stranici su oznaceni plavom ikonom, a izbrisani autori sa ikonicom korpe za smece.', # MODIF
	'info_gauche_messagerie' => 'Servis za slanje poruka vam omogucuje razmjenu poruka medju piscima, cuvanje biljeske (za licnu upotrebu) ili, ako ste administrator, postavljanje najava na pocetnu stranicu u privatnom prostoru.', # MODIF
	'info_gauche_statistiques_referers' => 'Ova strana predstavlja  listu <i>referenci</i>, sto znaci stranice koje sadrze linkove  sa vasom licnom stranicom, ali samo za jucer i danas; ova lista se vraca na nulu svaka 20 sata.',
	'info_gauche_visiteurs_enregistres' => 'Ovdje mozete pronaci posjetioce koji su registrovani na javnoj stranici (forumi za clanove).',
	'info_generation_miniatures_images' => 'Obradjivanje minijaturnih slika',
	'info_hebergeur_desactiver_envoi_email' => 'Neki kompjuteri dezaktiviraju automatsko slanje mailova njihovim serverima. U tom slucaju sljedece funkcije SPIP-a nece biti u uptrebi.',
	'info_hier' => 'Jucer:',
	'info_identification_publique' => 'Vas javni identitet...',
	'info_image_process' => 'Izaberite najbolju metodu pravljenja vinjeta tako sto cete kliknuti na odgovarajucu sliku.',
	'info_image_process2' => '<b>N.B.</b> <i>Ako se ne pojavljuje nijedna slika, onda vas server nije konfigurisan za koristenje tih funkcija. Ako zelite koristiti te funkcije, kontaktirajte ososbu odgovornu za tehnicko odrzavanje i pitajte za extenzije «GD» ili  «Imagick».</i>', # MODIF
	'info_images_auto' => 'Automatski izracunate slike',
	'info_informations_personnelles' => 'Peta etapa: <b>Licne informacije</b>', # MODIF
	'info_inscription_automatique' => 'Automatsko upisivanje novih urednika', # MODIF
	'info_jeu_caractere' => 'Set karaktera stranice',
	'info_jours' => 'dani',
	'info_laisser_champs_vides' => 'ostavi ova polja prazna)',
	'info_langues' => 'Jezici stranice',
	'info_ldap_ok' => 'LDAP autentifikacija je instalirana.',
	'info_lien_hypertexte' => 'Hiperlink:',
	'info_liste_redacteurs_connectes' => 'Lista konektovanih urednika', # MODIF
	'info_login_existant' => 'Ovaj login vec postoji.',
	'info_login_trop_court' => 'Ovaj login je prekratak.',
	'info_maximum' => 'maksimalno:',
	'info_meme_rubrique' => 'U istoj rubrici',
	'info_message_en_redaction' => 'Vase poruke u toku uredjivanja',
	'info_message_technique' => 'Tehnicka poruka:',
	'info_messagerie_interne' => 'Interni servis za poruke',
	'info_mise_a_niveau_base' => 'nadogradnja vase SQL baze', # MODIF
	'info_mise_a_niveau_base_2' => '\\{\\{Paznja!\\}\\} Instalirali ste verziju SPIP dokumenata, koji su stariji od one koja je vec postojala na stranici: vasa baza podataka je vjerovatno izgubljena i vasa stranica vise nece funkcionisati.  <br />\\{\\{Ponovo instalirajte SPIP dokumente\\}\\}', # MODIF
	'info_modifier_rubrique' => 'Izmijeni rubriku:',
	'info_modifier_titre' => 'Izmijeni: @titre@',
	'info_mon_site_spip' => 'Moja SPIP stranica',
	'info_moyenne' => 'prosjek:',
	'info_multi_cet_article' => 'Jezik ovog clanka:',
	'info_multi_langues_choisies' => 'Izaberite jezike koji ce biti na raspolaganju urednicima vase stranice. Jezici koji se vec koriste na vasoj stranici, ne mogu se iskluciti.', # MODIF
	'info_multi_secteurs' => '... samo za rubrike koje se nalaze na root-u?',
	'info_nom' => 'Ime',
	'info_nom_destinataire' => 'Ime primaoca',
	'info_nom_site' => 'Ime vase stranice',
	'info_nombre_articles' => '@nb_articles@ clanci,',
	'info_nombre_rubriques' => '@nb_rubriques@ rubrike,',
	'info_nombre_sites' => '@nb_sites@ stranice,',
	'info_non_deplacer' => 'Ne premijestati...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP moze regularno poslati najavu posljednjih novosti stranice (recentno objavljeni clanci i kratke poruke).',
	'info_non_envoi_liste_nouveautes' => 'Ne slati listu novosti',
	'info_non_modifiable' => 'Ne moze se modifikovati',
	'info_non_suppression_mot_cle' => 'Ne zelim izbrisati ovu kljucnu rijec.',
	'info_notes' => 'Biljeske',
	'info_nouvel_article' => 'Novi clanak',
	'info_nouvelle_traduction' => 'Novi prevod:',
	'info_numero_article' => 'CLANAK BROJ:',
	'info_obligatoire_02' => '[Obavezno]', # MODIF
	'info_option_accepter_visiteurs' => 'Prihvati upisivanje posjetioca na javnoj stranici', # MODIF
	'info_option_ne_pas_accepter_visiteurs' => 'Odbij upisivanje posjetioca', # MODIF
	'info_options_avancees' => 'NAPREDNE OPCIJE',
	'info_ou' => 'ili...',
	'info_page_interdite' => 'Ova strana je zabranjena',
	'info_par_nombre_article' => '(po broju clanaka)', # MODIF
	'info_passe_trop_court' => 'Prekratka lozinka.',
	'info_passes_identiques' => 'Lozinke nisu identicne.',
	'info_plus_cinq_car' => 'vise od pet karaktera',
	'info_plus_cinq_car_2' => '(Vise od pet karaktera)',
	'info_plus_trois_car' => '(Vise od tri karaktera)',
	'info_popularite' => 'popularnosti: @popularite@ ;  posjete: @visites@',
	'info_post_scriptum' => 'Post-Scriptum',
	'info_post_scriptum_2' => 'Post-scriptum :',
	'info_pour' => 'za',
	'info_preview_texte' => 'Moguce je stranicu pogledati online, kao da su svi clanci i kratke poruke objavljene, ukoliko iste imaju « predlozen » status. Da li ova opcija treba biti otvorena samo administratorima, svim urednicima ili nikome?', # MODIF
	'info_procedez_par_etape' => 'Slijedite etape',
	'info_procedure_maj_version' => 'Potrebno je pokrenuti update, da bi se baza podataka prikljucila novoj verziji SPIP-a.',
	'info_ps' => 'P.S.:', # MODIF
	'info_publier' => 'objavi moje clanke',
	'info_question_accepter_visiteurs' => 'Ako obrasci vase stranice ukljucuju upisivanje posjetioca bez pristupa u  privatnu stranicu, aktivirajte sljedecu opciju:', # MODIF
	'info_question_inscription_nouveaux_redacteurs' => 'Da li prihvatate upisivanje novih urednika u javnom prostoru  stranice? Ako prihvatate, posjetioci ce se moci registrovati putem automatskog formulara, a zatim ce moci pristupiti privatnom prostoru i predlagati svoje clanke. <blockquote><i>Tokom faze upisivanja, korisnici ce primiti  automatski e-mail sa kodom za pristup u privatnu stranicu. Neki kompjuteri sprecavaju slanje mailova putem njihovih servera: u tom slucaju ce automatsko upisivanje biti nemoguce.', # MODIF
	'info_qui_edite' => '@nom_auteur_modif@ a travaillé sur ce contenu il y a @date_diff@ minutes', # MODIF
	'info_racine_site' => 'Korjen stranice',
	'info_recharger_page' => 'Restartujte ovu stranicu za nekoliko momenata.',
	'info_recherche_auteur_zero' => 'Nema rezultata za « @cherche_auteur@ ».',
	'info_recommencer' => 'Pocnite ponovo.',
	'info_redacteur_1' => 'Urednik',
	'info_redacteur_2' => 'koji ima/ju pristup privatnoj stranici (<i>recommandé</i>)',
	'info_redacteurs' => 'Urednici',
	'info_redaction_en_cours' => 'U TOKU UREDJIVANJA',
	'info_redirection' => 'Preusmjerenje',
	'info_refuses' => 'Vasi odbijeni clanci',
	'info_reglage_ldap' => 'Opcije: namijestanje LDAP importa</b>', # MODIF
	'info_renvoi_article' => '<b>Preusmjerenje.</b> Ovaj clanak se preusmjerava na stranicu:', # MODIF
	'info_reserve_admin' => 'Samo administratori mogu izmijeniti ovu adresu.', # MODIF
	'info_restreindre_rubrique' => 'Ograniciti uredjivanje rubrike:',
	'info_resultat_recherche' => 'Rezultati pretrage:',
	'info_rubriques' => 'Rubrike',
	'info_rubriques_02' => 'rubrike',
	'info_rubriques_trouvees' => 'Pronadjene rubrike',
	'info_sans_titre' => 'Bez naslova',
	'info_selection_chemin_acces' => '<b>Izaberite</b> putanju pristupa direktoriju:',
	'info_signatures' => 'potpisi',
	'info_site' => 'Stranica',
	'info_site_2' => 'stranica:',
	'info_site_min' => 'stranica',
	'info_site_reference_2' => 'Preporucena stranica',
	'info_site_web' => 'WEB STRANICA :', # MODIF
	'info_sites' => 'stranice',
	'info_sites_lies_mot' => 'Preporucene stranice koje su vezane za ovu kljucnu rijec',
	'info_sites_proxy' => 'Koristi proxy',
	'info_sites_trouves' => 'Pronadjene stranice',
	'info_sous_titre' => 'Podnaslov:',
	'info_statut_administrateur' => 'Administrator', # MODIF
	'info_statut_auteur' => 'Status ovog autora:', # MODIF
	'info_statut_redacteur' => 'Urednik',
	'info_statut_utilisateurs_1' => 'Standardni status importovanih korisnika', # MODIF
	'info_statut_utilisateurs_2' => 'Izaberita koji status ce imati osobe koje su prisutne u LDAP direktoriju, kada se konektuju  prvi put. Kasnije ce te biti u mogucnosti da status svakog autora individualno izmijenite.', # MODIF
	'info_suivi_activite' => 'Pracenje urednicke aktivnosti',
	'info_surtitre' => 'Nadnaslov:',
	'info_taille_maximale_vignette' => 'Maksimalna velicina vinjeta  koje uredjuje sistem:',
	'info_terminer_installation' => 'Sada mozete zavrsiti standardnu proceduru instalacije.',
	'info_texte' => 'Tekst',
	'info_texte_explicatif' => 'Eksplikacioni tekst',
	'info_texte_long' => '(Ovaj tekst je dug, a zato je prikazan u vise dijelova, koji ce biti sastavljeni poslije ovjere.)',
	'info_texte_message' => 'Tekst vase poruke:', # MODIF
	'info_texte_message_02' => 'Tekst poruke',
	'info_titre' => 'Naslov:',
	'info_total' => 'total:',
	'info_tous_articles_en_redaction' => 'Svi clanci koji su fazi obradjivanja',
	'info_tous_articles_presents' => 'Svi objavljeni clanci u ovoj rubrici',
	'info_tous_les' => 'svi:',
	'info_tout_site' => 'Citava web stranica',
	'info_tout_site2' => 'Clanak nije preveden na ovaj jezik.',
	'info_tout_site3' => 'Clanak je preveden na ovaj jezik, ali su usvojene izmjene preporucenog clanka. Potrebno je obnoviti  prevod.',
	'info_tout_site4' => 'Clanak je preveden na ovaj jezik i prevod je obnovljen.',
	'info_tout_site5' => 'Originalni clanak.',
	'info_tout_site6' => '<b>Paznja:</b> prikazani su samo originalni clanci.
Prevodi su (sa bojom koja ukazuje na njihovo stanje) povezani sa originalnim clankom:',
	'info_travail_colaboratif' => 'Saradnicki rad na clancima',
	'info_un_article' => 'clanak,',
	'info_un_site' => 'jedna stranica,',
	'info_une_rubrique' => 'jedna rubrika,',
	'info_une_rubrique_02' => '1 rubrika',
	'info_url' => 'URL:',
	'info_urlref' => 'Hiperlink:',
	'info_utilisation_spip' => 'Mozete poceti sa koristenjem sistema za asistirano objavljivanje...',
	'info_visites_par_mois' => 'Prikazi po mjesecu:',
	'info_visiteur_1' => 'posjetioc',
	'info_visiteur_2' => 'javne stranice',
	'info_visiteurs' => 'posjetioci',
	'info_visiteurs_02' => 'Posjetioci javne stranice',
	'install_echec_annonce' => 'Instalacija vjerovatno nece uspjeti, ili ce rezultirati nefunkcionirajucom stranicom...',
	'install_extension_mbstring' => 'SPIP ne funkcionise sa:',
	'install_extension_php_obligatoire' => 'SPIP-u je potrebna php ekstenzija:',
	'install_select_langue' => 'Izaberite jezik, a zatim kliknite na dugme « sljedece » da bi pokrenuli proces instalacije.',
	'intem_redacteur' => 'urednik',
	'item_accepter_inscriptions' => 'Prihvati upise',
	'item_activer_messages_avertissement' => 'Aktiviraj poruke upozorenja',
	'item_administrateur_2' => 'administrator', # MODIF
	'item_afficher_calendrier' => 'Prikazati u kalendaru',
	'item_choix_administrateurs' => 'administratori', # MODIF
	'item_choix_generation_miniature' => 'Automatski uredi minijature slika.',
	'item_choix_non_generation_miniature' => 'Ne uredjuj minijature slika.',
	'item_choix_redacteurs' => 'urednici',
	'item_choix_visiteurs' => 'posjetioci javne stranice',
	'item_creer_fichiers_authent' => 'kreiraj dokumente .htpasswd',
	'item_login' => 'Login',
	'item_mots_cles_association_articles' => 'za clanke',
	'item_mots_cles_association_rubriques' => 'za rubrike',
	'item_mots_cles_association_sites' => 'Za preporucene ili sindikovane stranice.',
	'item_non' => 'Ne',
	'item_non_accepter_inscriptions' => 'Ne dozvoljavaj upise',
	'item_non_activer_messages_avertissement' => 'Bez poruka upozorenja',
	'item_non_afficher_calendrier' => 'Ne prikazuj u kalendaru',
	'item_non_creer_fichiers_authent' => 'Ne kreiraj ove dokumente',
	'item_non_publier_articles' => 'Ne objavljuj clanke poslije datuma odredjenog za publikaciju.',
	'item_nouvel_auteur' => 'Novi autor',
	'item_nouvelle_rubrique' => 'Nova rubrika',
	'item_oui' => 'Da',
	'item_publier_articles' => 'Objavi clanke bez obzira na datum odredjen za njihovu publikaciju.',
	'item_reponse_article' => 'Odgovor na clanak',
	'item_visiteur' => 'posjetioc',

	// J
	'jour_non_connu_nc' => 'nepoznato',

	// L
	'lien_ajouter_auteur' => 'Dodaj ovog autora',
	'lien_email' => 'e-mail',
	'lien_nom_site' => 'IME STRANICE:',
	'lien_retirer_auteur' => 'Odstrani autora',
	'lien_site' => 'stranica',
	'lien_tout_deplier' => 'Sve otvoriti',
	'lien_tout_replier' => 'Sve zatvoriti',
	'lien_trier_nom' => 'Poredaj po imenu',
	'lien_trier_nombre_articles' => 'Poredaj po broju clanaka',
	'lien_trier_statut' => 'Poredaj po statusu',
	'lien_voir_en_ligne' => 'POGLEDAJ ONLINE:',
	'logo_article' => 'LOGOTIP CLANKA', # MODIF
	'logo_auteur' => 'LOGOTIP AUTORA', # MODIF
	'logo_rubrique' => 'LOGOTIP RUBRIKE', # MODIF
	'logo_site' => 'LOGOTIP STRANICE', # MODIF
	'logo_standard_rubrique' => 'STANDARDNI LOGOTIP ZA RUBRIKE', # MODIF
	'logo_survol' => 'HOVERING LOGO', # MODIF

	// M
	'menu_aide_installation_choix_base' => 'Biranje vase baze',
	'module_fichier_langue' => 'Jezicni dokument',
	'module_raccourci' => 'Precica',
	'module_texte_affiche' => 'Prikazani tekst',
	'module_texte_explicatif' => 'Mozete dodati sljedece precice u obrasce vase javne stranice. One ce biti automatski prevedene u razne jezike, za koje postoje jezicni dokumenti.',
	'module_texte_traduction' => 'Jezicni dokument « @module@ » je na raspolaganju u:',
	'mois_non_connu' => 'nepoznato',

	// O
	'onglet_repartition_actuelle' => 'Aktuelno',

	// P
	'plugin_etat_developpement' => 'u razvoju',
	'plugin_etat_experimental' => 'experimentalno',
	'plugin_etat_stable' => 'stabilno',
	'plugin_etat_test' => 'testira se',
	'plugins_liste' => 'Plugin lista',

	// R
	'repertoire_plugins' => 'Directorij:',
	'required' => '[Obavezno]', # MODIF

	// S
	'statut_admin_restreint' => '(ograniceni admin)', # MODIF

	// T
	'taille_cache_image' => 'Slike koje SPIP automatski izracunava (vinjete dokumenata, naslove predstavljene u grafickoj formi, matematicke funkcije u TeX formatu ...) zauzimaju u @dir@  repertoaru total od @taille@.',
	'taille_cache_octets' => 'Aktuelna velicina kesa je @octets@.', # MODIF
	'taille_cache_vide' => 'Kes je prazan.',
	'taille_repertoire_cache' => 'Aktuelna velicina kesa',
	'text_article_propose_publication' => 'Clanak predlozen za objavljivanje. Ne oklijevajte da date vase misljenje u forumu dodanom ovom clanku (na dnu ove strane).', # MODIF
	'texte_acces_ldap_anonyme_1' => 'Neki LDAP serveri ne prihvataju ni jedan anonimni pristup. U tom slucaju je potrebno odrediti identifikatora za inicijalni pristup, da bi zatim postojala mogucnost pretrage informacija u direktoriju. U vecini slucajeva, sljedeca polja mogu ostati prazna',
	'texte_admin_effacer_01' => 'Ova komanda ce izbrisati <i>sav</i> sadrzaj baze podataka, ukljucujuci <i>sve</i> pristupe urednika i administratora. Prije nego je pokrenete,  trebate pokrenuti reinstalaciju pristupa SPIP-u da biste kreirali novu bazu, kao i prvi pristup administratora.', # MODIF
	'texte_adresse_annuaire_1' => '(Ako je vas direktorij instaliran na istoj masini kao ova web stranica, vjerovatno se radi o localhost-u.)',
	'texte_ajout_auteur' => 'Sljedeci autor je dodan clanku:',
	'texte_annuaire_ldap_1' => 'Ako imate pristup jednom (LDAP) direktoriju, mozete ga koristiti za automatsko importovanje korisnika u SPIP.', # MODIF
	'texte_article_statut' => 'Ovaj clanak je:',
	'texte_article_virtuel' => 'Virtuelni clanak',
	'texte_article_virtuel_reference' => '<b>Virtuelni clanak:</b> clanak je preporucen na vasoj SPIP stranici, ali apreusmjeren na drugi URL. Da bi ste sprijecili preusmjeravanje, izbrisite nize prikazani URL.',
	'texte_aucun_resultat_auteur' => 'Nema rezultata za"@cherche_auteur@"',
	'texte_auteur_messagerie' => 'Ova stranica vam moze permanentno ukazivati na listu konektovanih urednika, sto vam omogucuje online razmjenu poruka. Mozete odluciti da se ne pojavljujete na ovoj listi (nevidljivi ste za druge korisnike).', # MODIF
	'texte_auteurs' => 'AUTORI',
	'texte_choix_base_1' => 'Izaberite vasu bazu:',
	'texte_choix_base_2' => 'SQL server sadrzi vise baza podataka.', # MODIF
	'texte_choix_base_3' => '<b>Izaberite</b> Ispod one koja vam je dodjeljena od vaseg kompjutera:', # MODIF
	'texte_compte_element' => '@count@ element',
	'texte_compte_elements' => '@count@ elementi',
	'texte_connexion_mysql' => 'Provjerite informacije koje ste dobili od vaseg kompjutera: Trebate pronaci da li vas kompjuter podrzava SQL i kodove za konekciju na SQL  server.', # MODIF
	'texte_contenu_article' => '(Sadrzaj clanka u nekoliko rijeci.)',
	'texte_contenu_articles' => 'Prema rasporedu koji je prihvacen za vasu stranicu, mozete odluciti da se neki elementi clanaka ne koriste. Koristite se sa nize prikazanom listom i naznacite koji su elementi dostupni.',
	'texte_crash_base' => 'Ako je vasa baza podataka pala, mozete pokusati automatsku popravku.',
	'texte_creer_rubrique' => 'Prije pisanja clanaka,<br /> trebate kreirati rubriku.', # MODIF
	'texte_date_creation_article' => 'DATUM NASTANKA CLANKA:',
	'texte_date_publication_anterieure' => 'Datum proslog uredjivanja:',
	'texte_date_publication_anterieure_nonaffichee' => 'Ne prikazuj datum proslog uredjivanja.',
	'texte_date_publication_article' => 'DATUM OBJAVLJIVANJA:',
	'texte_descriptif_rapide' => 'Brzi opis',
	'texte_effacer_base' => 'Izbrisati SPIP bazu podataka',
	'texte_en_cours_validation' => 'Dole navedeni clanci i kratke poruke su predlozene za publikaciju. Vase misljenje mozete iznijeti u njima prikljucenim forumima.', # MODIF
	'texte_enrichir_mise_a_jour' => 'Mozete obogatiti izgled vaseg teksta na stranici, koristeci se « tipogrfskim  precicama ».',
	'texte_fichier_authent' => '<b>Treba li SPIP kreirati specijalne dokumente <tt>.htpasswd</tt> i  <tt>.htpasswd-admin</tt> u repertoaru @dossier@ ?</b><p> Ti dokumenti vam omogucuju zabranu pristupa autorima  i administratorima na drugim mjestima vase stranice (npr.  eksterni program za statistike).</p><p>  Ako od ovoga nemate  nikakve koristi, mozete ostaviti standardnu vrijednost za ovu  opciju (nema kreacije dokumenata).</p>', # MODIF
	'texte_informations_personnelles_1' => 'Sistem ce sada kreirati  personalizovan pistup stranici.',
	'texte_informations_personnelles_2' => '(Napomena: ako se radi o reinstalaciji i ako vas pristup uvijek funkcionise, mozete', # MODIF
	'texte_introductif_article' => '(Uvodni tekst u clanak.)',
	'texte_jeu_caractere' => 'Ova opcija je korisna ako vasa  stranica treba postavljati tekstove sa alfabetom (ukljucujuci  njegove derivate) koji nije romanski (ili  « okcidentalni »). U tom slucaju je  pozeljno promijeniti standardnu postavku u odgovarajuci set  karaktera; u svakum slucaju vam savjetujemo da napravite  testove i pronadjete zadovoljavajuce rijesenje. Ako izmlijenite  ovaj parametar, ne zaboravite javnu stranicu prilagoditi  izmjenama (balise <tt>#CHARSET</tt>).',
	'texte_login_ldap_1' => '(Ostaviti prazno za anonimni pristup ili unjeti kompletnu putanju, npr. « <tt>uid=dupont,  ou=users, dc=mon-domaine, dc=com</tt> ».)',
	'texte_login_precaution' => 'Paznja! Ovo je login kojim ste trenutno konektovani. Pazljivo se koristite ovim  formularom...',
	'texte_mise_a_niveau_base_1' => 'Upravo ste obnovili SPIP dokumente. Sada je potrebna nadogrdnja baze podataka.',
	'texte_modifier_article' => 'Izmijeni clanak:',
	'texte_multilinguisme' => 'Ako zelita obradjivati clanke na vise jezika, sa kompleksnom navigacijom, u organizaciju vase  stranice mozete dodati meni za odabir jezika u clancima i/ili  rubrikama.', # MODIF
	'texte_multilinguisme_trad' => 'Svakako mozete aktivirati sistem sa obradjivanje linkova izmedju razlicitih prevoda  clanaka.', # MODIF
	'texte_non_compresse' => '<i>nije kompresovan</i> (vas server ne podrzava ovu funkciju)',
	'texte_nouvelle_version_spip_1' => 'Instalirali ste novu verziju SPIP-a.',
	'texte_nouvelle_version_spip_2' => 'Ovoj verziji je potrebno obnavljanje kompletnije od uobicajenog. Ako ste webmaster stranice, izbrisite dokument <tt>inc_connect.php3</tt> iz  repertoara <tt>ecrire</tt> i ponovo otpocnite instalaciju da  biste obnovili parametre konekcije sa bazom podataka.<p>  (Napomena: ako ste zaboravili parametre vase konekcije  pogledajte dokument <tt>inc_connect.php3</tt> prije nego ga  izbrisete...)</p>', # MODIF
	'texte_operation_echec' => 'Vratite se na prethodnu stranu, izaberite drugu bazu ili napravite novu. Provjerite podatke  koje vam je dao vas kompjuter.',
	'texte_plus_trois_car' => 'vise od tri karaktera',
	'texte_plusieurs_articles' => 'Pronadjeno vise autora za "@cherche_auteur@":',
	'texte_port_annuaire' => '(Naznacena standardna vrijednost odgovara u vecini slucajeva.)',
	'texte_proposer_publication' => 'Kada zavrsite vas clanak,<br /> mozete predloziti njegovo objavljivanje.', # MODIF
	'texte_proxy' => 'U odredjenim slucajevima (intranet, zasticene  mreze...), koristenje <i>proxy HTTP</i> moze biti neophodno za dostizanje sindikovanih stranica. Ako je potrebno, naznacite adresu u sljedecoj formi <tt><html>http://proxy:8080</html></tt>. U vecini slucajeva, ovo polje mozete ostaviti prazno.', # MODIF
	'texte_publication_articles_post_dates' => 'Kako se SPIP treba ponasati prema clancima ciji je datum objavljivanja odredjen za buducnost? ',
	'texte_rappel_selection_champs' => '[Ne zaboravite ispravno izabrati ovo polje.]',
	'texte_recalcul_page' => 'Ako zelite preracunati samo jednu stranu, predjite u javni prostor i koristite « preracunati ».',
	'texte_recuperer_base' => 'Popravi bazu podataka',
	'texte_reference_mais_redirige' => 'clanak je preporucen u vasoj SPIP stranici, ali je preusmjeren na drugi URL.',
	'texte_requetes_echouent' => '<b>Ako odredzeni SQL zahtijevi sistematski i bez ociglednog razloga ne uspijevaju, moguce je da je problem u samoj bazi podataka.</b><p> SQL raspolaze mogucnosti popravljanja njegovih tabela, ako su one slucajno ostecene. Ovdje mozete isprobati popravku; u slucaju neuspijeha, sacuvajte kopiju prikaza na monitoru, koja mozda sadrzi naznake problema...</p><p> Ako se problem nastavi, kontaktirajte vas hosting servis.</p>', # MODIF
	'texte_selection_langue_principale' => 'Mozete izabrati « glavni jezik » stranice. Taj izbor vas (na srecu!) ne obavezuje na pisanje clanaka na tom jeziku, ali dozvoljava odredjivanje:
\\tab <ul><li> standardni format datuma na javnoj stranici;</li>
\\tab <li> prirodu tipografskog motora koj ce SPIP koristriti za izradu tekstova;</li>
\\tab <li> jezik koji ce se koristiti u formularima javne stranice;</li>
\\tab <li> standardni jezik, prisutan na privatnoj stranici.</li></ul>',
	'texte_sous_titre' => 'Podnaslov',
	'texte_statistiques_visites' => '(tamne trake:  nedjelja / tamna kriva: prosjecni nivo)',
	'texte_statut_attente_validation' => 'na cekanju za ovjeru',
	'texte_statut_publies' => 'objavljeni',
	'texte_statut_refuses' => 'odbijeni',
	'texte_suppression_fichiers' => 'Koristite se ovom komandom da biste sve prisutne dokumente u SPIP kes. To omogucuje npr. izazivanje preracunavanja svih strana, u slucaju da ste izveli vazne izmjene grafizma ili strukture stranice.',
	'texte_sur_titre' => 'Nadnaslov',
	'texte_table_ok' => ':ova tabela je OK.',
	'texte_tentative_recuperation' => 'Pokusaj popravke',
	'texte_tenter_reparation' => 'Pokusati popravljanje baze podataka',
	'texte_test_proxy' => 'Da bi ste probali ovaj proxy, ovdje naznacite adresu (web stranice) koju zelite testirati.',
	'texte_titre_02' => 'Naslov:',
	'texte_titre_obligatoire' => '<b>Naslov</b> [Obavezan]', # MODIF
	'texte_travail_article' => '@nom_auteur_modif@ ostaje @date_diff@ minuta za rad na ovom clanku',
	'texte_travail_collaboratif' => 'Ako je uobicajeno da vise urednika radi na istom clanku, sistem moze postavljati posljednje « otvarane » clanke, da bi se izbjegle simultane izmjene. Ova opcija je standardno iskljucena, da bi se izbjeglo postavljanje neodgovarajucih poruka upozorenja.', # MODIF
	'texte_vide' => 'prazno',
	'texte_vider_cache' => 'Isprazniti kes',
	'titre_admin_tech' => 'Tehnicko odrzavanje',
	'titre_cadre_afficher_article' => 'Prikazi clanke',
	'titre_cadre_afficher_traductions' => 'Prikazi stanje prevoda za sljedece jezike:',
	'titre_cadre_ajouter_auteur' => 'DODATI AUTORA:',
	'titre_cadre_interieur_rubrique' => 'U unutrasnjosti rubrike',
	'titre_cadre_numero_auteur' => 'AUTOR BROJ',
	'titre_cadre_signature_obligatoire' => '<b>Potpis</b>  [Obavezno]<br />', # MODIF
	'titre_config_fonctions' => 'Konfiguracija stranice',
	'titre_configuration' => 'Konfiguracija stranice',
	'titre_connexion_ldap' => 'Opcije: <b>Vasa LDAP konekcija</b>',
	'titre_groupe_mots' => 'GRUPA RIJECI:',
	'titre_langue_article' => 'JEZIK CLANKA', # MODIF
	'titre_langue_rubrique' => 'JEZIK RUBRIKE', # MODIF
	'titre_langue_trad_article' => 'JEZIK I PREVOD CLANKA',
	'titre_les_articles' => 'CLANCI',
	'titre_naviguer_dans_le_site' => 'Navigacija stranicom...',
	'titre_nouvelle_rubrique' => 'Nova rubrika',
	'titre_numero_rubrique' => 'RUBRIKA BROJ:',
	'titre_page_articles_edit' => 'Izmjeni: @titre@',
	'titre_page_articles_page' => 'Clanci',
	'titre_page_articles_tous' => 'Cijela stranica',
	'titre_page_calendrier' => 'Kalendar @nom_mois@ @annee@',
	'titre_page_config_contenu' => 'Konfiguracija stranice',
	'titre_page_delete_all' => 'cjelokupno i nepovratno otklanjanje',
	'titre_page_recherche' => 'Rezultati pretrage @recherche@',
	'titre_page_statistiques_referers' => 'Statistike (linkovi unosenja)',
	'titre_page_upgrade' => 'Postavljanje SPIP-a na aktuelni nivo',
	'titre_publication_articles_post_dates' => 'Objavljivanje clanaka sa kasnijim datumom',
	'titre_reparation' => 'Popravka',
	'titre_suivi_petition' => 'Pracenje peticija',
	'trad_article_traduction' => 'Sve verzije ovog clanka:',
	'trad_delier' => 'Ne vezati vise ovaj clanak za ove prevode', # MODIF
	'trad_lier' => 'Ovaj clanak je prevod clanka broj:',
	'trad_new' => 'Napisati novi prevod ovog clanka', # MODIF
];
